@@ -9,7 +9,8 @@ import json
 import pymongo
 import tldextract
 import re
-
+import base64
+import hashlib
 class BHunters(Karton):
     def __init__(self, *args, **kwargs) -> None:  # type: ignore[no-untyped-def]
         config = Config(path="/etc/b-hunters/b-hunters.ini")
@@ -150,4 +151,20 @@ class BHunters(Karton):
         db = client[db]
         return db    
 
- 
\ No newline at end of file
+    def encode_filename(self, url_or_path):
+        """
+        Encodes a URL or path to be a valid filename by replacing unsupported characters.
+        """
+        # Define characters that are not typically allowed in filenames
+        invalid_chars = r'[<>:"/\\|?*]'
+        
+        # Replace invalid characters with underscores
+        safe_name = re.sub(invalid_chars, '_', url_or_path)
+        
+        # Ensure the filename isn't too long (max 255 characters is a common limit)
+        if len(safe_name) > 255:
+            # If it's too long, hash it to ensure uniqueness
+            hash_object = hashlib.md5(url_or_path.encode())
+            safe_name = hash_object.hexdigest()
+        
+        return safe_name
\ No newline at end of file
